package com.ruoyi.system.service;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.system.domain.TPatientHospitalDoctor;
import com.ruoyi.system.domain.TRecord;
import com.ruoyi.system.domain.req.TRecordResultReq;
import com.ruoyi.system.domain.resp.PatientHistoryRecordResp;
import com.ruoyi.system.domain.resp.TRecordResp;

/**
 * 诊断记录信息Service接口
 *
 * @author ruoyi
 * @date 2022-08-03
 */
public interface ITRecordService
{
    /**
     * 查询诊断记录信息
     *
     * @param id 诊断记录信息主键
     * @return 诊断记录信息
     */
    public TRecord selectTRecordById(Long id);

    /**
     * 查询诊断记录信息列表
     *
     * @param tRecord 诊断记录信息
     * @return 诊断记录信息集合
     */
    public List<TRecord> selectTRecordList(TRecord tRecord);

    /**
     * 新增诊断记录信息
     *
     * @param tRecord 诊断记录信息
     * @return 结果
     */
    public int insertTRecord(TRecord tRecord);

    /**
     * 修改诊断记录信息
     *
     * @param tRecord 诊断记录信息
     * @return 结果
     */
    public int updateTRecord(TRecord tRecord);

    /**
     * 批量删除诊断记录信息
     *
     * @param ids 需要删除的诊断记录信息主键集合
     * @return 结果
     */
    public int deleteTRecordByIds(Long[] ids);

    /**
     * 删除诊断记录信息信息
     *
     * @param id 诊断记录信息主键
     * @return 结果
     */
    public int deleteTRecordById(Long id);

    /**
     * 查询就诊记录信息列表
     *
     * @param tRecord 查询参数
     * @return 结果
     */
    List<TRecordResp> selectTRecordListWithoutResult(TRecordResultReq tRecord);

    List<TRecordResp> queryHomePatientList(TRecordResultReq tRecord);

    /**
     * 根据患者记录id查询就诊记录详情
     *
     * @param id 查询参数
     * @return 结果
     */
    TRecordResp selectById(Long id);

    /**
     * 通过病人医院医生id查询记录列表
     *
     * @param tPatientHospitalDoctor t病人医院医生
     * @return {@code List<TRecord>}
     */
    public List<TRecordResp> queryRecordListByPHDids(TPatientHospitalDoctor tPatientHospitalDoctor);

    /**
     *
     * 查询患者历史数据图表
     * @param tRecord 患者记录
     * @return {@code AjaxResult}
     */
    AjaxResult getHistoryList(TRecord tRecord);

    /**
     * 查询医生诊断次数
     *
     * @param doctorId 医生id
     * @return int
     */
    int queryDoctorNumberOfDiagnosis(Long doctorId);

    List<PatientHistoryRecordResp> queryPatientHistoryRecord(TRecord tRecord);
}
