package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.TImage;
import com.ruoyi.system.domain.TImageHistory;
import com.ruoyi.system.domain.TRecord;
import com.ruoyi.system.service.ITImageHistoryService;
import com.ruoyi.system.service.ITImageService;
import com.ruoyi.system.service.ITRecordService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TRecordHistoryMapper;
import com.ruoyi.system.domain.TRecordHistory;
import com.ruoyi.system.service.ITRecordHistoryService;

/**
 * 诊断记录信息历史Service业务层处理
 * 
 * @author ruoyi
 * @date 2022-09-13
 */
@Service
public class TRecordHistoryServiceImpl implements ITRecordHistoryService 
{
    @Autowired
    private TRecordHistoryMapper tRecordHistoryMapper;
    @Autowired
    private ITRecordService tRecordService;
    @Autowired
    private ITImageHistoryService imageHistoryService;
    @Autowired
    private ITImageService imageService;


    /**
     * 查询诊断记录信息历史
     * 
     * @param id 诊断记录信息历史主键
     * @return 诊断记录信息历史
     */
    @Override
    public TRecordHistory selectTRecordHistoryById(Long id)
    {
        return tRecordHistoryMapper.selectTRecordHistoryById(id);
    }

    /**
     * 查询诊断记录信息历史列表
     * 
     * @param tRecordHistory 诊断记录信息历史
     * @return 诊断记录信息历史
     */
    @Override
    public List<TRecordHistory> selectTRecordHistoryList(TRecordHistory tRecordHistory)
    {
        return tRecordHistoryMapper.selectTRecordHistoryList(tRecordHistory);
    }

    /**
     * 新增诊断记录信息历史
     * 
     * @param tRecordHistory 诊断记录信息历史
     * @return 结果
     */
    @Override
    public int insertTRecordHistory(TRecordHistory tRecordHistory)
    {
        tRecordHistory.setCreateTime(DateUtils.getNowDate());
        return tRecordHistoryMapper.insertTRecordHistory(tRecordHistory);
    }

    /**
     * 修改诊断记录信息历史
     * 
     * @param tRecordHistory 诊断记录信息历史
     * @return 结果
     */
    @Override
    public int updateTRecordHistory(TRecordHistory tRecordHistory)
    {
        tRecordHistory.setUpdateTime(DateUtils.getNowDate());
        return tRecordHistoryMapper.updateTRecordHistory(tRecordHistory);
    }

    /**
     * 批量删除诊断记录信息历史
     * 
     * @param ids 需要删除的诊断记录信息历史主键
     * @return 结果
     */
    @Override
    public int deleteTRecordHistoryByIds(Long[] ids)
    {
        return tRecordHistoryMapper.deleteTRecordHistoryByIds(ids);
    }

    /**
     * 删除诊断记录信息历史信息
     * 
     * @param id 诊断记录信息历史主键
     * @return 结果
     */
    @Override
    public int deleteTRecordHistoryById(Long id)
    {
        return tRecordHistoryMapper.deleteTRecordHistoryById(id);
    }

    @Override
    public void saveHistory(Long recordId) {
        TRecord tRecord = tRecordService.selectTRecordById(recordId);
        TRecordHistory tRecordHistory = new TRecordHistory();
        BeanUtils.copyProperties(tRecord,tRecordHistory);

        tRecordHistory.setRecodeId(recordId);
        tRecordHistory.setId(null);
        //备份记录表
        tRecordHistoryMapper.insertTRecordHistory(tRecordHistory);

        //备份图片表
        TImage tImage = new TImage();
        tImage.setThirdId(recordId);
        List<TImage> images = imageService.selectTImageList(tImage);

        images.parallelStream().forEach(x->{
            TImageHistory tImageHistory=new TImageHistory();
            BeanUtils.copyProperties(x,tImageHistory);

            tImageHistory.setId(null);
            tImageHistory.setThirdId(tRecordHistory.getId());
            imageHistoryService.insertTImageHistory(tImageHistory);
        });
    }
}
